@@ -466,9 +466,13 @@ func (opts *healthCheckOptions) toHealthConfig() (*container.HealthConfig, error
 }
 
 // convertExtraHostsToSwarmHosts converts an array of extra hosts in cli
-//     <host>:<ip>
+//
+//	<host>:<ip>
+//
 // into a swarmkit host format:
-//     IP_address canonical_hostname [aliases...]
+//
+//	IP_address canonical_hostname [aliases...]
+//
 // This assumes input value (<host>:<ip>) has already been validated
 func convertExtraHostsToSwarmHosts(extraHosts []string) []string {
 	hosts := []string{}
@@ -914,7 +918,7 @@ func addServiceFlags(flags *pflag.FlagSet, opts *serviceOptions, defaultFlagValu
 }
 
 const (
-	flagCredentialSpec          = "credential-spec"
+	flagCredentialSpec          = "credential-spec" //nolint:gosec // ignore G101: Potential hardcoded credentials
 	flagPlacementPref           = "placement-pref"
 	flagPlacementPrefAdd        = "placement-pref-add"
 	flagPlacementPrefRemove     = "placement-pref-rm"
